@@ -5,13 +5,13 @@ Defines a request dispatcher, a HTTP request handler, a HTTP server and a
 CGI request handler.
 
 :authors: Josh Marshall, Thomas Calmant
-:copyright: Copyright 2019, Thomas Calmant
+:copyright: Copyright 2020, Thomas Calmant
 :license: Apache License 2.0
-:version: 0.4.0
+:version: 0.4.1
 
 ..
 
-    Copyright 2019 Thomas Calmant
+    Copyright 2020 Thomas Calmant
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -81,7 +81,7 @@ import jsonrpclib.threadpool
 # ------------------------------------------------------------------------------
 
 # Module version
-__version_info__ = (0, 4, 0)
+__version_info__ = (0, 4, 1)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
@@ -442,7 +442,7 @@ class SimpleJSONRPCRequestHandler(SimpleXMLRPCRequestHandler):
                 if not raw_chunk:
                     break
                 chunks.append(utils.from_bytes(raw_chunk))
-                size_remaining -= len(chunks[-1])
+                size_remaining -= len(raw_chunk)
             data = ''.join(chunks)
 
             try:
